@@ -24,10 +24,12 @@
 #'
 #' @examples
 #' \donttest{
+#' if (requireNamespace("rstan", quietly = TRUE)) {
 #' # Note we recommend setting n.burn and n.iter to larger values
 #' radegger_fit <- mr_radialegger_stan(bmi_insulin, n.burn = 500, n.iter = 1000)
 #' print(radegger_fit)
 #' }
+#' }
 mr_radialegger_stan <- function(data,
                           prior = 1,
                           n.chains = 3,
@@ -37,6 +39,9 @@ mr_radialegger_stan <- function(data,
                           seed = 12345,
                           ...) {
 
+  # check for rstan
+  rstan_check()
+
   # convert MRInput object to mr_format
   if ("MRInput" %in% class(data)) {
     data <- mrinput_mr_format(data)
